@@ -1,5 +1,6 @@
 from manageprojects.utilities.publish import publish_package
 from manageprojects.utilities.subprocess_utils import verbose_check_call
+from rich.pretty import pprint
 
 from manage_django_project.config import project_info
 from manage_django_project.management.base import BaseManageCommand
@@ -21,7 +22,11 @@ class Command(BaseManageCommand):
         self.publish()
 
     def publish(self):
-        publish_package(
+        kwargs = dict(
             module=project_info.config.module,
             package_path=project_info.config.project_root_path,
+            distribution_name=project_info.distribution_name,
         )
+        print('Start publishing with:')
+        pprint(kwargs)
+        publish_package(**kwargs)
